@@ -84,7 +84,7 @@ class ZincWizard(object):
             "password": "Please enter your Amazon password"
             },
         "shipping_address": {
-            "start_message": "\nNow we'd like to get your shipping information. Don't worry if you make a mistake,\nwe'll ask you to verify the correctness of your address so you can retype it if you'd like.",
+            "start_message": "\nNow we'd like to get your shipping information. Don't worry if you make a mistake,\nwe'll ask you to verify the correctness of your address so you can retype it if you'd like.\n",
             "end_message": "\nYou've finished entering your shipping address!"
             },
         "address": {
